Struct memsocket::MemorySocket [−][src]
pub struct MemorySocket { /* fields omitted */ }Expand description
An in-memory stream between two local sockets.
A MemorySocket can either be created by connecting to an endpoint, via the
connect method, or by accepting a connection from a listener.
It can be read or written to using the AsyncRead, AsyncWrite, and related
extension traits in futures::io.
Examples
use futures::prelude::*;
use memsocket::MemorySocket;
let (mut socket_a, mut socket_b) = MemorySocket::new_pair();
socket_a.write_all(b"stormlight").await?;
socket_a.flush().await?;
let mut buf = [0; 10];
socket_b.read_exact(&mut buf).await?;
assert_eq!(&buf, b"stormlight");
Implementations
Construct both sides of an in-memory socket.
Examples
use memsocket::MemorySocket;
let (socket_a, socket_b) = MemorySocket::new_pair();Trait Implementations
Attempt to read from the AsyncRead into buf.
Attempt to write bytes from buf into the outgoing channel.
Attempt to flush the channel. Cannot Fail.
Attempt to close the channel. Cannot Fail.